@@ -549,13 +549,13 @@ quan_mobile_server <- function(input, output, session){
                          "Mode" = MODE,
                          "Strip" = input$selectStrip,
                          BG.method, AM, Med,
-                         check.names = FALSE)
+                         check.names = TRUE)
       }else{
         DF <- data.frame("File" = shinyImageFile$filename,
                          "Mode" = NA,
                          "Strip" = input$selectStrip,
                          BG.method, AM, Med,
-                         check.names = FALSE)
+                         check.names = TRUE)
       }
       if(inherits(try(IntensData, silent = TRUE), "try-error"))
         IntensData <<- DF
@@ -621,7 +621,7 @@ quan_mobile_server <- function(input, output, session){
       req(input$intensFile)
       tryCatch(
         DF <- read.csv(input$intensFile$datapath, header = TRUE,
-                       check.names = FALSE),
+                       check.names = TRUE),
         error = function(e){stop(safeError(e))}
       )
       IntensData <<- DF
